summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDave Jones <davej@codemonkey.org.uk>2003-04-10 14:29:55 +0100
committerDave Jones <davej@codemonkey.org.uk>2003-04-10 14:29:55 +0100
commit42b413a93383cdf2d2f0c6c1771bc922f7ad8236 (patch)
tree9d94b4dfb3e1f4c0552778b31a60a4b0ddbacfda
parent5edf8b9a4208987e60e0f41aff0bcc298641c0ad (diff)
[AGPGART] Fix up AMD64 references.
Spotted by Andi Kleen. AMD64 is the architecture, not the CPU.
-rw-r--r--drivers/char/agp/amd-k8-agp.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/drivers/char/agp/amd-k8-agp.c b/drivers/char/agp/amd-k8-agp.c
index faefa5fbb0ad..036fc9937106 100644
--- a/drivers/char/agp/amd-k8-agp.c
+++ b/drivers/char/agp/amd-k8-agp.c
@@ -2,7 +2,7 @@
* Copyright 2001-2003 SuSE Labs.
* Distributed under the GNU public license, v2.
*
* This is a GART driver for the AMD64 on-CPU northbridge.
* It also includes support for the AMD 8151 AGP bridge,
* although it doesn't actually do much, as all the real
* work is done in the northbridge(s).
@@ -340,7 +340,7 @@ static int __init agp_amdk8_probe (struct pci_dev *dev, const struct pci_device_
if (cap_ptr == 0)
return -ENODEV;
- printk (KERN_INFO PFX "Detected AMD64 on-CPU GART\n");
+ printk (KERN_INFO PFX "Detected Opteron/Athlon64 on-CPU GART\n");
agp_bridge->dev = dev;
agp_bridge->capndx = cap_ptr;
@@ -2,7 +2,7 @@
* Distributed under the GNU public license, v2.
*
- * This is a GART driver for the AMD64 on-CPU northbridge.
+ * This is a GART driver for the AMD Opteron/Athlon64 on-CPU northbridge.
* It also includes support for the AMD 8151 AGP bridge,
* although it doesn't actually do much, as all the real